
Starting Frontend Excel
=======================================================================

The production Soakdb3 frontend excel is started from a batch file in the visit/processing/lab36 directory.

You will need to get a copy of the batch file for each visit::

    $ ssh i04-1-ws004
    $ cp /dls_sw/apps/xchem/soakdb3/soakdb3_configuration/soakDB3.bat /dls/labxchem/data/<visit>/<visit>-1/processing/lab36

Now, from the Windows explorer, navigate to::
    
    Y:\<visit>\<visit>-1\processing\lab36

Then double-click soakdDB3.bat.

